uni.pt: Shrinkage Estimation for the Univariate Normal Mean based on a Preliminary Test Estimator
Description
This function computes a preliminary test (pretest) estimate for the univariate normal mean.
This function also computes the confidence interval based on a pretest estimator.